@@ -492,32 +492,33 @@ class DataTransformerForm(BaseInlineFormSet):
                                                              fk_name='parent',
                                                              extra=1, exclude=['updated_at', 'created_at'], form=DataTransform
                                                              )
-        form.nested_data_transformer_form = dataTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None,
-            extra=1)
+        if form.instance is not None:
+            form.nested_data_transformer_form = dataTransformerInlineFormset(
+                instance=form.instance,
+                data=form.data if form.is_bound else None,
+                files=form.files if form.is_bound else None
+            )
 
-        form.nested_constants_form = DataConstantsTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None,
-            extra=1)
+            form.nested_constants_form = DataConstantsTransformerInlineFormset(
+                instance=form.instance,
+                data=form.data if form.is_bound else None,
+                files=form.files if form.is_bound else None
+            )
 
-        form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None,
-            extra=1)
+            form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
+                instance=form.instance,
+                data=form.data if form.is_bound else None,
+                files=form.files if form.is_bound else None
+            )
 
-        form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None,
-            extra=1)
+            form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+                instance=form.instance,
+                data=form.data if form.is_bound else None,
+                files=form.files if form.is_bound else None
+            )
 
     def as_p(self):
-        forms = ' '.join(' '.join([form.as_p(),form.nested_data_transformer_form,form.nested_constants_form,form.nested_hardware_outputs_form,form.nested_hardware_stats_form]) for form in self)
+        forms = ' '.join(' '.join([form.as_p(),form.nested_data_transformer_form.as_p(),form.nested_constants_form.as_p(),form.nested_hardware_outputs_form.as_p(),form.nested_hardware_stats_form.as_p()]) for form in self)
         return mark_safe(str(self.management_form) + '\n' + forms)
 
 
